const {constants, log, helpers} = require('utils-nxg-cg');
const {objectDb, extraProps} = require('./objects');
const process = require('./process');

/**
 * Method for process the data user and execute query single or batch by transactions
 * @param msg
 * @param cfg
 * @param test
 * @returns {Promise<array|object>}
 */
module.exports.processQuery = async (msg = {}, cfg = {}, test = false) => {
    return new Promise(async (resolve, reject) => {
        try {
            log.info('Inside processQuery');
            /*if (JSON.stringify(msg).length <= 10000)
                log.debug('Msg=', JSON.stringify(msg));*/
            if (JSON.stringify(cfg).length <= 10000)
                log.debug('Config=', JSON.stringify(cfg));

            const {data} = msg;

            let properties = {...objectDb};
            let extraProp = {...extraProps};

            if (!test && !data) {
                throw Error(`${constants.ERROR_PROPERTY} data`);
            }
            const valid = await helpers.validProperties(properties, data, cfg);

            if (valid) {
                await helpers.validProperties(extraProp, data, cfg, true);
                properties = {...properties, ...extraProp};
                if (properties.content) {
                    if (typeof properties.content === 'string') {
                        //for to base64
                        if (constants.Base64Regex.test(properties.content) || constants.Base64Regexp.test(properties.content)) {
                            properties.content = JSON.parse(helpers.convertBase64ToUtf8(properties.content));
                        } else {
                            properties.content = JSON.parse(properties.content);
                        }
                    }
                }
                const result = await process(properties);
                resolve(result);
            }
        } catch (e) {
            log.error(e);
            reject(e);
        }
    });
};